Class: LogStash::Inputs::Intercom
- Inherits:
-
Base
- Object
- Base
- LogStash::Inputs::Intercom
- Defined in:
- lib/logstash/inputs/intercom.rb
Overview
This plugin was created as a way to ingest data from Intercom into Logstash.
Usage:
Here is an example of setting up the plugin to fetch data from Intercom.
- source,ruby
input {
intercom { app_id => ":appId" app_api_key => ":appApiKey" sync_users => true sync_events => true flatten_excludes => [] }}
Instance Method Summary collapse
- #register ⇒ Object
-
#run(queue) ⇒ Object
def register.
-
#stop ⇒ Object
def run.
Instance Method Details
#register ⇒ Object
50 51 52 |
# File 'lib/logstash/inputs/intercom.rb', line 50 def register configure_intercom_client end |
#run(queue) ⇒ Object
def register
54 55 56 |
# File 'lib/logstash/inputs/intercom.rb', line 54 def run(queue) sync_all(queue) end |
#stop ⇒ Object
def run
58 59 |
# File 'lib/logstash/inputs/intercom.rb', line 58 def stop end |