Class: LogStash::Inputs::Intercom
- Inherits:
-
Base
- Object
- Base
- LogStash::Inputs::Intercom
- Defined in:
- lib/logstash/inputs/intercom.rb
Overview
This plugin was created as a way to ingest data from Intercom into Logstash.
Usage:
Here is an example of setting up the plugin to fetch data from Intercom.
- source,ruby
input {
intercom { app_id => ":appId" app_api_key => ":appApiKey" }}
Instance Method Summary collapse
- #register ⇒ Object
-
#run(queue) ⇒ Object
def register.
-
#stop ⇒ Object
def run.
Instance Method Details
#register ⇒ Object
44 45 46 |
# File 'lib/logstash/inputs/intercom.rb', line 44 def register configure_intercom_client end |
#run(queue) ⇒ Object
def register
48 49 50 |
# File 'lib/logstash/inputs/intercom.rb', line 48 def run(queue) sync_all(queue) end |
#stop ⇒ Object
def run
52 53 |
# File 'lib/logstash/inputs/intercom.rb', line 52 def stop end |